// Code generated by MockGen. DO NOT EDIT.
// Source: gitlab.com/gitlab-org/api/client-go/v2 (interfaces: RunnerControllerTokensServiceInterface)
//
// Generated by this command:
//
//	mockgen -typed -destination=runner_controller_tokens_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 RunnerControllerTokensServiceInterface
//

package testing

import (
	reflect "reflect"

	gitlab "gitlab.com/gitlab-org/api/client-go/v2"
	gomock "go.uber.org/mock/gomock"
)

// MockRunnerControllerTokensServiceInterface is a mock of RunnerControllerTokensServiceInterface interface.
type MockRunnerControllerTokensServiceInterface struct {
	ctrl     *gomock.Controller
	recorder *MockRunnerControllerTokensServiceInterfaceMockRecorder
	isgomock struct{}
}

// MockRunnerControllerTokensServiceInterfaceMockRecorder is the mock recorder for MockRunnerControllerTokensServiceInterface.
type MockRunnerControllerTokensServiceInterfaceMockRecorder struct {
	mock *MockRunnerControllerTokensServiceInterface
}

// NewMockRunnerControllerTokensServiceInterface creates a new mock instance.
func NewMockRunnerControllerTokensServiceInterface(ctrl *gomock.Controller) *MockRunnerControllerTokensServiceInterface {
	mock := &MockRunnerControllerTokensServiceInterface{ctrl: ctrl}
	mock.recorder = &MockRunnerControllerTokensServiceInterfaceMockRecorder{mock}
	return mock
}

// EXPECT returns an object that allows the caller to indicate expected use.
func (m *MockRunnerControllerTokensServiceInterface) EXPECT() *MockRunnerControllerTokensServiceInterfaceMockRecorder {
	return m.recorder
}

// CreateRunnerControllerToken mocks base method.
func (m *MockRunnerControllerTokensServiceInterface) CreateRunnerControllerToken(rid int64, opt *gitlab.CreateRunnerControllerTokenOptions, options ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerToken, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "CreateRunnerControllerToken", varargs...)
	ret0, _ := ret[0].(*gitlab.RunnerControllerToken)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// CreateRunnerControllerToken indicates an expected call of CreateRunnerControllerToken.
func (mr *MockRunnerControllerTokensServiceInterfaceMockRecorder) CreateRunnerControllerToken(rid, opt any, options ...any) *MockRunnerControllerTokensServiceInterfaceCreateRunnerControllerTokenCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "CreateRunnerControllerToken", reflect.TypeOf((*MockRunnerControllerTokensServiceInterface)(nil).CreateRunnerControllerToken), varargs...)
	return &MockRunnerControllerTokensServiceInterfaceCreateRunnerControllerTokenCall{Call: call}
}

// MockRunnerControllerTokensServiceInterfaceCreateRunnerControllerTokenCall wrap *gomock.Call
type MockRunnerControllerTokensServiceInterfaceCreateRunnerControllerTokenCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllerTokensServiceInterfaceCreateRunnerControllerTokenCall) Return(arg0 *gitlab.RunnerControllerToken, arg1 *gitlab.Response, arg2 error) *MockRunnerControllerTokensServiceInterfaceCreateRunnerControllerTokenCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllerTokensServiceInterfaceCreateRunnerControllerTokenCall) Do(f func(int64, *gitlab.CreateRunnerControllerTokenOptions, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerToken, *gitlab.Response, error)) *MockRunnerControllerTokensServiceInterfaceCreateRunnerControllerTokenCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllerTokensServiceInterfaceCreateRunnerControllerTokenCall) DoAndReturn(f func(int64, *gitlab.CreateRunnerControllerTokenOptions, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerToken, *gitlab.Response, error)) *MockRunnerControllerTokensServiceInterfaceCreateRunnerControllerTokenCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// GetRunnerControllerToken mocks base method.
func (m *MockRunnerControllerTokensServiceInterface) GetRunnerControllerToken(rid, tokenID int64, options ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerToken, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid, tokenID}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "GetRunnerControllerToken", varargs...)
	ret0, _ := ret[0].(*gitlab.RunnerControllerToken)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// GetRunnerControllerToken indicates an expected call of GetRunnerControllerToken.
func (mr *MockRunnerControllerTokensServiceInterfaceMockRecorder) GetRunnerControllerToken(rid, tokenID any, options ...any) *MockRunnerControllerTokensServiceInterfaceGetRunnerControllerTokenCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid, tokenID}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "GetRunnerControllerToken", reflect.TypeOf((*MockRunnerControllerTokensServiceInterface)(nil).GetRunnerControllerToken), varargs...)
	return &MockRunnerControllerTokensServiceInterfaceGetRunnerControllerTokenCall{Call: call}
}

// MockRunnerControllerTokensServiceInterfaceGetRunnerControllerTokenCall wrap *gomock.Call
type MockRunnerControllerTokensServiceInterfaceGetRunnerControllerTokenCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllerTokensServiceInterfaceGetRunnerControllerTokenCall) Return(arg0 *gitlab.RunnerControllerToken, arg1 *gitlab.Response, arg2 error) *MockRunnerControllerTokensServiceInterfaceGetRunnerControllerTokenCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllerTokensServiceInterfaceGetRunnerControllerTokenCall) Do(f func(int64, int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerToken, *gitlab.Response, error)) *MockRunnerControllerTokensServiceInterfaceGetRunnerControllerTokenCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllerTokensServiceInterfaceGetRunnerControllerTokenCall) DoAndReturn(f func(int64, int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerToken, *gitlab.Response, error)) *MockRunnerControllerTokensServiceInterfaceGetRunnerControllerTokenCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// ListRunnerControllerTokens mocks base method.
func (m *MockRunnerControllerTokensServiceInterface) ListRunnerControllerTokens(rid int64, opt *gitlab.ListRunnerControllerTokensOptions, options ...gitlab.RequestOptionFunc) ([]*gitlab.RunnerControllerToken, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "ListRunnerControllerTokens", varargs...)
	ret0, _ := ret[0].([]*gitlab.RunnerControllerToken)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// ListRunnerControllerTokens indicates an expected call of ListRunnerControllerTokens.
func (mr *MockRunnerControllerTokensServiceInterfaceMockRecorder) ListRunnerControllerTokens(rid, opt any, options ...any) *MockRunnerControllerTokensServiceInterfaceListRunnerControllerTokensCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "ListRunnerControllerTokens", reflect.TypeOf((*MockRunnerControllerTokensServiceInterface)(nil).ListRunnerControllerTokens), varargs...)
	return &MockRunnerControllerTokensServiceInterfaceListRunnerControllerTokensCall{Call: call}
}

// MockRunnerControllerTokensServiceInterfaceListRunnerControllerTokensCall wrap *gomock.Call
type MockRunnerControllerTokensServiceInterfaceListRunnerControllerTokensCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllerTokensServiceInterfaceListRunnerControllerTokensCall) Return(arg0 []*gitlab.RunnerControllerToken, arg1 *gitlab.Response, arg2 error) *MockRunnerControllerTokensServiceInterfaceListRunnerControllerTokensCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllerTokensServiceInterfaceListRunnerControllerTokensCall) Do(f func(int64, *gitlab.ListRunnerControllerTokensOptions, ...gitlab.RequestOptionFunc) ([]*gitlab.RunnerControllerToken, *gitlab.Response, error)) *MockRunnerControllerTokensServiceInterfaceListRunnerControllerTokensCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllerTokensServiceInterfaceListRunnerControllerTokensCall) DoAndReturn(f func(int64, *gitlab.ListRunnerControllerTokensOptions, ...gitlab.RequestOptionFunc) ([]*gitlab.RunnerControllerToken, *gitlab.Response, error)) *MockRunnerControllerTokensServiceInterfaceListRunnerControllerTokensCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// RevokeRunnerControllerToken mocks base method.
func (m *MockRunnerControllerTokensServiceInterface) RevokeRunnerControllerToken(rid, tokenID int64, options ...gitlab.RequestOptionFunc) (*gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid, tokenID}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "RevokeRunnerControllerToken", varargs...)
	ret0, _ := ret[0].(*gitlab.Response)
	ret1, _ := ret[1].(error)
	return ret0, ret1
}

// RevokeRunnerControllerToken indicates an expected call of RevokeRunnerControllerToken.
func (mr *MockRunnerControllerTokensServiceInterfaceMockRecorder) RevokeRunnerControllerToken(rid, tokenID any, options ...any) *MockRunnerControllerTokensServiceInterfaceRevokeRunnerControllerTokenCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid, tokenID}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "RevokeRunnerControllerToken", reflect.TypeOf((*MockRunnerControllerTokensServiceInterface)(nil).RevokeRunnerControllerToken), varargs...)
	return &MockRunnerControllerTokensServiceInterfaceRevokeRunnerControllerTokenCall{Call: call}
}

// MockRunnerControllerTokensServiceInterfaceRevokeRunnerControllerTokenCall wrap *gomock.Call
type MockRunnerControllerTokensServiceInterfaceRevokeRunnerControllerTokenCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllerTokensServiceInterfaceRevokeRunnerControllerTokenCall) Return(arg0 *gitlab.Response, arg1 error) *MockRunnerControllerTokensServiceInterfaceRevokeRunnerControllerTokenCall {
	c.Call = c.Call.Return(arg0, arg1)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllerTokensServiceInterfaceRevokeRunnerControllerTokenCall) Do(f func(int64, int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockRunnerControllerTokensServiceInterfaceRevokeRunnerControllerTokenCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllerTokensServiceInterfaceRevokeRunnerControllerTokenCall) DoAndReturn(f func(int64, int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockRunnerControllerTokensServiceInterfaceRevokeRunnerControllerTokenCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// RotateRunnerControllerToken mocks base method.
func (m *MockRunnerControllerTokensServiceInterface) RotateRunnerControllerToken(rid, tokenID int64, options ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerToken, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid, tokenID}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "RotateRunnerControllerToken", varargs...)
	ret0, _ := ret[0].(*gitlab.RunnerControllerToken)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// RotateRunnerControllerToken indicates an expected call of RotateRunnerControllerToken.
func (mr *MockRunnerControllerTokensServiceInterfaceMockRecorder) RotateRunnerControllerToken(rid, tokenID any, options ...any) *MockRunnerControllerTokensServiceInterfaceRotateRunnerControllerTokenCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid, tokenID}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "RotateRunnerControllerToken", reflect.TypeOf((*MockRunnerControllerTokensServiceInterface)(nil).RotateRunnerControllerToken), varargs...)
	return &MockRunnerControllerTokensServiceInterfaceRotateRunnerControllerTokenCall{Call: call}
}

// MockRunnerControllerTokensServiceInterfaceRotateRunnerControllerTokenCall wrap *gomock.Call
type MockRunnerControllerTokensServiceInterfaceRotateRunnerControllerTokenCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllerTokensServiceInterfaceRotateRunnerControllerTokenCall) Return(arg0 *gitlab.RunnerControllerToken, arg1 *gitlab.Response, arg2 error) *MockRunnerControllerTokensServiceInterfaceRotateRunnerControllerTokenCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllerTokensServiceInterfaceRotateRunnerControllerTokenCall) Do(f func(int64, int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerToken, *gitlab.Response, error)) *MockRunnerControllerTokensServiceInterfaceRotateRunnerControllerTokenCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllerTokensServiceInterfaceRotateRunnerControllerTokenCall) DoAndReturn(f func(int64, int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerToken, *gitlab.Response, error)) *MockRunnerControllerTokensServiceInterfaceRotateRunnerControllerTokenCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}
