// Code generated by MockGen. DO NOT EDIT.
// Source: gitlab.com/gitlab-org/api/client-go/v2 (interfaces: SecurityCategoriesServiceInterface)
//
// Generated by this command:
//
//	mockgen -typed -destination=security_categories_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SecurityCategoriesServiceInterface
//

package testing

import (
	reflect "reflect"

	gitlab "gitlab.com/gitlab-org/api/client-go/v2"
	gomock "go.uber.org/mock/gomock"
)

// MockSecurityCategoriesServiceInterface is a mock of SecurityCategoriesServiceInterface interface.
type MockSecurityCategoriesServiceInterface struct {
	ctrl     *gomock.Controller
	recorder *MockSecurityCategoriesServiceInterfaceMockRecorder
	isgomock struct{}
}

// MockSecurityCategoriesServiceInterfaceMockRecorder is the mock recorder for MockSecurityCategoriesServiceInterface.
type MockSecurityCategoriesServiceInterfaceMockRecorder struct {
	mock *MockSecurityCategoriesServiceInterface
}

// NewMockSecurityCategoriesServiceInterface creates a new mock instance.
func NewMockSecurityCategoriesServiceInterface(ctrl *gomock.Controller) *MockSecurityCategoriesServiceInterface {
	mock := &MockSecurityCategoriesServiceInterface{ctrl: ctrl}
	mock.recorder = &MockSecurityCategoriesServiceInterfaceMockRecorder{mock}
	return mock
}

// EXPECT returns an object that allows the caller to indicate expected use.
func (m *MockSecurityCategoriesServiceInterface) EXPECT() *MockSecurityCategoriesServiceInterfaceMockRecorder {
	return m.recorder
}

// CreateSecurityCategory mocks base method.
func (m *MockSecurityCategoriesServiceInterface) CreateSecurityCategory(namespaceID int64, opt *gitlab.CreateSecurityCategoryOptions, options ...gitlab.RequestOptionFunc) (*gitlab.SecurityCategory, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{namespaceID, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "CreateSecurityCategory", varargs...)
	ret0, _ := ret[0].(*gitlab.SecurityCategory)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// CreateSecurityCategory indicates an expected call of CreateSecurityCategory.
func (mr *MockSecurityCategoriesServiceInterfaceMockRecorder) CreateSecurityCategory(namespaceID, opt any, options ...any) *MockSecurityCategoriesServiceInterfaceCreateSecurityCategoryCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{namespaceID, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "CreateSecurityCategory", reflect.TypeOf((*MockSecurityCategoriesServiceInterface)(nil).CreateSecurityCategory), varargs...)
	return &MockSecurityCategoriesServiceInterfaceCreateSecurityCategoryCall{Call: call}
}

// MockSecurityCategoriesServiceInterfaceCreateSecurityCategoryCall wrap *gomock.Call
type MockSecurityCategoriesServiceInterfaceCreateSecurityCategoryCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockSecurityCategoriesServiceInterfaceCreateSecurityCategoryCall) Return(arg0 *gitlab.SecurityCategory, arg1 *gitlab.Response, arg2 error) *MockSecurityCategoriesServiceInterfaceCreateSecurityCategoryCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockSecurityCategoriesServiceInterfaceCreateSecurityCategoryCall) Do(f func(int64, *gitlab.CreateSecurityCategoryOptions, ...gitlab.RequestOptionFunc) (*gitlab.SecurityCategory, *gitlab.Response, error)) *MockSecurityCategoriesServiceInterfaceCreateSecurityCategoryCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockSecurityCategoriesServiceInterfaceCreateSecurityCategoryCall) DoAndReturn(f func(int64, *gitlab.CreateSecurityCategoryOptions, ...gitlab.RequestOptionFunc) (*gitlab.SecurityCategory, *gitlab.Response, error)) *MockSecurityCategoriesServiceInterfaceCreateSecurityCategoryCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// DestroySecurityCategory mocks base method.
func (m *MockSecurityCategoriesServiceInterface) DestroySecurityCategory(id int64, options ...gitlab.RequestOptionFunc) (*gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{id}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "DestroySecurityCategory", varargs...)
	ret0, _ := ret[0].(*gitlab.Response)
	ret1, _ := ret[1].(error)
	return ret0, ret1
}

// DestroySecurityCategory indicates an expected call of DestroySecurityCategory.
func (mr *MockSecurityCategoriesServiceInterfaceMockRecorder) DestroySecurityCategory(id any, options ...any) *MockSecurityCategoriesServiceInterfaceDestroySecurityCategoryCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{id}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "DestroySecurityCategory", reflect.TypeOf((*MockSecurityCategoriesServiceInterface)(nil).DestroySecurityCategory), varargs...)
	return &MockSecurityCategoriesServiceInterfaceDestroySecurityCategoryCall{Call: call}
}

// MockSecurityCategoriesServiceInterfaceDestroySecurityCategoryCall wrap *gomock.Call
type MockSecurityCategoriesServiceInterfaceDestroySecurityCategoryCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockSecurityCategoriesServiceInterfaceDestroySecurityCategoryCall) Return(arg0 *gitlab.Response, arg1 error) *MockSecurityCategoriesServiceInterfaceDestroySecurityCategoryCall {
	c.Call = c.Call.Return(arg0, arg1)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockSecurityCategoriesServiceInterfaceDestroySecurityCategoryCall) Do(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockSecurityCategoriesServiceInterfaceDestroySecurityCategoryCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockSecurityCategoriesServiceInterfaceDestroySecurityCategoryCall) DoAndReturn(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockSecurityCategoriesServiceInterfaceDestroySecurityCategoryCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// UpdateSecurityCategory mocks base method.
func (m *MockSecurityCategoriesServiceInterface) UpdateSecurityCategory(id, namespaceID int64, opt *gitlab.UpdateSecurityCategoryOptions, options ...gitlab.RequestOptionFunc) (*gitlab.SecurityCategory, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{id, namespaceID, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "UpdateSecurityCategory", varargs...)
	ret0, _ := ret[0].(*gitlab.SecurityCategory)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// UpdateSecurityCategory indicates an expected call of UpdateSecurityCategory.
func (mr *MockSecurityCategoriesServiceInterfaceMockRecorder) UpdateSecurityCategory(id, namespaceID, opt any, options ...any) *MockSecurityCategoriesServiceInterfaceUpdateSecurityCategoryCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{id, namespaceID, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "UpdateSecurityCategory", reflect.TypeOf((*MockSecurityCategoriesServiceInterface)(nil).UpdateSecurityCategory), varargs...)
	return &MockSecurityCategoriesServiceInterfaceUpdateSecurityCategoryCall{Call: call}
}

// MockSecurityCategoriesServiceInterfaceUpdateSecurityCategoryCall wrap *gomock.Call
type MockSecurityCategoriesServiceInterfaceUpdateSecurityCategoryCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockSecurityCategoriesServiceInterfaceUpdateSecurityCategoryCall) Return(arg0 *gitlab.SecurityCategory, arg1 *gitlab.Response, arg2 error) *MockSecurityCategoriesServiceInterfaceUpdateSecurityCategoryCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockSecurityCategoriesServiceInterfaceUpdateSecurityCategoryCall) Do(f func(int64, int64, *gitlab.UpdateSecurityCategoryOptions, ...gitlab.RequestOptionFunc) (*gitlab.SecurityCategory, *gitlab.Response, error)) *MockSecurityCategoriesServiceInterfaceUpdateSecurityCategoryCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockSecurityCategoriesServiceInterfaceUpdateSecurityCategoryCall) DoAndReturn(f func(int64, int64, *gitlab.UpdateSecurityCategoryOptions, ...gitlab.RequestOptionFunc) (*gitlab.SecurityCategory, *gitlab.Response, error)) *MockSecurityCategoriesServiceInterfaceUpdateSecurityCategoryCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}
