// Code generated by MockGen. DO NOT EDIT.
// Source: gitlab.com/gitlab-org/api/client-go/v2 (interfaces: RunnerControllersServiceInterface)
//
// Generated by this command:
//
//	mockgen -typed -destination=runner_controllers_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 RunnerControllersServiceInterface
//

package testing

import (
	reflect "reflect"

	gitlab "gitlab.com/gitlab-org/api/client-go/v2"
	gomock "go.uber.org/mock/gomock"
)

// MockRunnerControllersServiceInterface is a mock of RunnerControllersServiceInterface interface.
type MockRunnerControllersServiceInterface struct {
	ctrl     *gomock.Controller
	recorder *MockRunnerControllersServiceInterfaceMockRecorder
	isgomock struct{}
}

// MockRunnerControllersServiceInterfaceMockRecorder is the mock recorder for MockRunnerControllersServiceInterface.
type MockRunnerControllersServiceInterfaceMockRecorder struct {
	mock *MockRunnerControllersServiceInterface
}

// NewMockRunnerControllersServiceInterface creates a new mock instance.
func NewMockRunnerControllersServiceInterface(ctrl *gomock.Controller) *MockRunnerControllersServiceInterface {
	mock := &MockRunnerControllersServiceInterface{ctrl: ctrl}
	mock.recorder = &MockRunnerControllersServiceInterfaceMockRecorder{mock}
	return mock
}

// EXPECT returns an object that allows the caller to indicate expected use.
func (m *MockRunnerControllersServiceInterface) EXPECT() *MockRunnerControllersServiceInterfaceMockRecorder {
	return m.recorder
}

// CreateRunnerController mocks base method.
func (m *MockRunnerControllersServiceInterface) CreateRunnerController(opt *gitlab.CreateRunnerControllerOptions, options ...gitlab.RequestOptionFunc) (*gitlab.RunnerController, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "CreateRunnerController", varargs...)
	ret0, _ := ret[0].(*gitlab.RunnerController)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// CreateRunnerController indicates an expected call of CreateRunnerController.
func (mr *MockRunnerControllersServiceInterfaceMockRecorder) CreateRunnerController(opt any, options ...any) *MockRunnerControllersServiceInterfaceCreateRunnerControllerCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "CreateRunnerController", reflect.TypeOf((*MockRunnerControllersServiceInterface)(nil).CreateRunnerController), varargs...)
	return &MockRunnerControllersServiceInterfaceCreateRunnerControllerCall{Call: call}
}

// MockRunnerControllersServiceInterfaceCreateRunnerControllerCall wrap *gomock.Call
type MockRunnerControllersServiceInterfaceCreateRunnerControllerCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllersServiceInterfaceCreateRunnerControllerCall) Return(arg0 *gitlab.RunnerController, arg1 *gitlab.Response, arg2 error) *MockRunnerControllersServiceInterfaceCreateRunnerControllerCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllersServiceInterfaceCreateRunnerControllerCall) Do(f func(*gitlab.CreateRunnerControllerOptions, ...gitlab.RequestOptionFunc) (*gitlab.RunnerController, *gitlab.Response, error)) *MockRunnerControllersServiceInterfaceCreateRunnerControllerCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllersServiceInterfaceCreateRunnerControllerCall) DoAndReturn(f func(*gitlab.CreateRunnerControllerOptions, ...gitlab.RequestOptionFunc) (*gitlab.RunnerController, *gitlab.Response, error)) *MockRunnerControllersServiceInterfaceCreateRunnerControllerCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// DeleteRunnerController mocks base method.
func (m *MockRunnerControllersServiceInterface) DeleteRunnerController(rid int64, options ...gitlab.RequestOptionFunc) (*gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "DeleteRunnerController", varargs...)
	ret0, _ := ret[0].(*gitlab.Response)
	ret1, _ := ret[1].(error)
	return ret0, ret1
}

// DeleteRunnerController indicates an expected call of DeleteRunnerController.
func (mr *MockRunnerControllersServiceInterfaceMockRecorder) DeleteRunnerController(rid any, options ...any) *MockRunnerControllersServiceInterfaceDeleteRunnerControllerCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "DeleteRunnerController", reflect.TypeOf((*MockRunnerControllersServiceInterface)(nil).DeleteRunnerController), varargs...)
	return &MockRunnerControllersServiceInterfaceDeleteRunnerControllerCall{Call: call}
}

// MockRunnerControllersServiceInterfaceDeleteRunnerControllerCall wrap *gomock.Call
type MockRunnerControllersServiceInterfaceDeleteRunnerControllerCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllersServiceInterfaceDeleteRunnerControllerCall) Return(arg0 *gitlab.Response, arg1 error) *MockRunnerControllersServiceInterfaceDeleteRunnerControllerCall {
	c.Call = c.Call.Return(arg0, arg1)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllersServiceInterfaceDeleteRunnerControllerCall) Do(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockRunnerControllersServiceInterfaceDeleteRunnerControllerCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllersServiceInterfaceDeleteRunnerControllerCall) DoAndReturn(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockRunnerControllersServiceInterfaceDeleteRunnerControllerCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// GetRunnerController mocks base method.
func (m *MockRunnerControllersServiceInterface) GetRunnerController(rid int64, options ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerDetails, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "GetRunnerController", varargs...)
	ret0, _ := ret[0].(*gitlab.RunnerControllerDetails)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// GetRunnerController indicates an expected call of GetRunnerController.
func (mr *MockRunnerControllersServiceInterfaceMockRecorder) GetRunnerController(rid any, options ...any) *MockRunnerControllersServiceInterfaceGetRunnerControllerCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "GetRunnerController", reflect.TypeOf((*MockRunnerControllersServiceInterface)(nil).GetRunnerController), varargs...)
	return &MockRunnerControllersServiceInterfaceGetRunnerControllerCall{Call: call}
}

// MockRunnerControllersServiceInterfaceGetRunnerControllerCall wrap *gomock.Call
type MockRunnerControllersServiceInterfaceGetRunnerControllerCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllersServiceInterfaceGetRunnerControllerCall) Return(arg0 *gitlab.RunnerControllerDetails, arg1 *gitlab.Response, arg2 error) *MockRunnerControllersServiceInterfaceGetRunnerControllerCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllersServiceInterfaceGetRunnerControllerCall) Do(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerDetails, *gitlab.Response, error)) *MockRunnerControllersServiceInterfaceGetRunnerControllerCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllersServiceInterfaceGetRunnerControllerCall) DoAndReturn(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerDetails, *gitlab.Response, error)) *MockRunnerControllersServiceInterfaceGetRunnerControllerCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// ListRunnerControllers mocks base method.
func (m *MockRunnerControllersServiceInterface) ListRunnerControllers(opt *gitlab.ListRunnerControllersOptions, options ...gitlab.RequestOptionFunc) ([]*gitlab.RunnerController, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "ListRunnerControllers", varargs...)
	ret0, _ := ret[0].([]*gitlab.RunnerController)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// ListRunnerControllers indicates an expected call of ListRunnerControllers.
func (mr *MockRunnerControllersServiceInterfaceMockRecorder) ListRunnerControllers(opt any, options ...any) *MockRunnerControllersServiceInterfaceListRunnerControllersCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "ListRunnerControllers", reflect.TypeOf((*MockRunnerControllersServiceInterface)(nil).ListRunnerControllers), varargs...)
	return &MockRunnerControllersServiceInterfaceListRunnerControllersCall{Call: call}
}

// MockRunnerControllersServiceInterfaceListRunnerControllersCall wrap *gomock.Call
type MockRunnerControllersServiceInterfaceListRunnerControllersCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllersServiceInterfaceListRunnerControllersCall) Return(arg0 []*gitlab.RunnerController, arg1 *gitlab.Response, arg2 error) *MockRunnerControllersServiceInterfaceListRunnerControllersCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllersServiceInterfaceListRunnerControllersCall) Do(f func(*gitlab.ListRunnerControllersOptions, ...gitlab.RequestOptionFunc) ([]*gitlab.RunnerController, *gitlab.Response, error)) *MockRunnerControllersServiceInterfaceListRunnerControllersCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllersServiceInterfaceListRunnerControllersCall) DoAndReturn(f func(*gitlab.ListRunnerControllersOptions, ...gitlab.RequestOptionFunc) ([]*gitlab.RunnerController, *gitlab.Response, error)) *MockRunnerControllersServiceInterfaceListRunnerControllersCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// UpdateRunnerController mocks base method.
func (m *MockRunnerControllersServiceInterface) UpdateRunnerController(rid int64, opt *gitlab.UpdateRunnerControllerOptions, options ...gitlab.RequestOptionFunc) (*gitlab.RunnerController, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "UpdateRunnerController", varargs...)
	ret0, _ := ret[0].(*gitlab.RunnerController)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// UpdateRunnerController indicates an expected call of UpdateRunnerController.
func (mr *MockRunnerControllersServiceInterfaceMockRecorder) UpdateRunnerController(rid, opt any, options ...any) *MockRunnerControllersServiceInterfaceUpdateRunnerControllerCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "UpdateRunnerController", reflect.TypeOf((*MockRunnerControllersServiceInterface)(nil).UpdateRunnerController), varargs...)
	return &MockRunnerControllersServiceInterfaceUpdateRunnerControllerCall{Call: call}
}

// MockRunnerControllersServiceInterfaceUpdateRunnerControllerCall wrap *gomock.Call
type MockRunnerControllersServiceInterfaceUpdateRunnerControllerCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllersServiceInterfaceUpdateRunnerControllerCall) Return(arg0 *gitlab.RunnerController, arg1 *gitlab.Response, arg2 error) *MockRunnerControllersServiceInterfaceUpdateRunnerControllerCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllersServiceInterfaceUpdateRunnerControllerCall) Do(f func(int64, *gitlab.UpdateRunnerControllerOptions, ...gitlab.RequestOptionFunc) (*gitlab.RunnerController, *gitlab.Response, error)) *MockRunnerControllersServiceInterfaceUpdateRunnerControllerCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllersServiceInterfaceUpdateRunnerControllerCall) DoAndReturn(f func(int64, *gitlab.UpdateRunnerControllerOptions, ...gitlab.RequestOptionFunc) (*gitlab.RunnerController, *gitlab.Response, error)) *MockRunnerControllersServiceInterfaceUpdateRunnerControllerCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}
