// Code generated by MockGen. DO NOT EDIT.
// Source: gitlab.com/gitlab-org/api/client-go/v2 (interfaces: AttestationsServiceInterface)
//
// Generated by this command:
//
//	mockgen -typed -destination=attestations_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 AttestationsServiceInterface
//

package testing

import (
	reflect "reflect"

	gitlab "gitlab.com/gitlab-org/api/client-go/v2"
	gomock "go.uber.org/mock/gomock"
)

// MockAttestationsServiceInterface is a mock of AttestationsServiceInterface interface.
type MockAttestationsServiceInterface struct {
	ctrl     *gomock.Controller
	recorder *MockAttestationsServiceInterfaceMockRecorder
	isgomock struct{}
}

// MockAttestationsServiceInterfaceMockRecorder is the mock recorder for MockAttestationsServiceInterface.
type MockAttestationsServiceInterfaceMockRecorder struct {
	mock *MockAttestationsServiceInterface
}

// NewMockAttestationsServiceInterface creates a new mock instance.
func NewMockAttestationsServiceInterface(ctrl *gomock.Controller) *MockAttestationsServiceInterface {
	mock := &MockAttestationsServiceInterface{ctrl: ctrl}
	mock.recorder = &MockAttestationsServiceInterfaceMockRecorder{mock}
	return mock
}

// EXPECT returns an object that allows the caller to indicate expected use.
func (m *MockAttestationsServiceInterface) EXPECT() *MockAttestationsServiceInterfaceMockRecorder {
	return m.recorder
}

// DownloadAttestation mocks base method.
func (m *MockAttestationsServiceInterface) DownloadAttestation(pid any, attestationIID int64, options ...gitlab.RequestOptionFunc) ([]byte, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{pid, attestationIID}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "DownloadAttestation", varargs...)
	ret0, _ := ret[0].([]byte)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// DownloadAttestation indicates an expected call of DownloadAttestation.
func (mr *MockAttestationsServiceInterfaceMockRecorder) DownloadAttestation(pid, attestationIID any, options ...any) *MockAttestationsServiceInterfaceDownloadAttestationCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{pid, attestationIID}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "DownloadAttestation", reflect.TypeOf((*MockAttestationsServiceInterface)(nil).DownloadAttestation), varargs...)
	return &MockAttestationsServiceInterfaceDownloadAttestationCall{Call: call}
}

// MockAttestationsServiceInterfaceDownloadAttestationCall wrap *gomock.Call
type MockAttestationsServiceInterfaceDownloadAttestationCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockAttestationsServiceInterfaceDownloadAttestationCall) Return(arg0 []byte, arg1 *gitlab.Response, arg2 error) *MockAttestationsServiceInterfaceDownloadAttestationCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockAttestationsServiceInterfaceDownloadAttestationCall) Do(f func(any, int64, ...gitlab.RequestOptionFunc) ([]byte, *gitlab.Response, error)) *MockAttestationsServiceInterfaceDownloadAttestationCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockAttestationsServiceInterfaceDownloadAttestationCall) DoAndReturn(f func(any, int64, ...gitlab.RequestOptionFunc) ([]byte, *gitlab.Response, error)) *MockAttestationsServiceInterfaceDownloadAttestationCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// ListAttestations mocks base method.
func (m *MockAttestationsServiceInterface) ListAttestations(pid any, subjectDigest string, options ...gitlab.RequestOptionFunc) ([]*gitlab.Attestation, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{pid, subjectDigest}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "ListAttestations", varargs...)
	ret0, _ := ret[0].([]*gitlab.Attestation)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// ListAttestations indicates an expected call of ListAttestations.
func (mr *MockAttestationsServiceInterfaceMockRecorder) ListAttestations(pid, subjectDigest any, options ...any) *MockAttestationsServiceInterfaceListAttestationsCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{pid, subjectDigest}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "ListAttestations", reflect.TypeOf((*MockAttestationsServiceInterface)(nil).ListAttestations), varargs...)
	return &MockAttestationsServiceInterfaceListAttestationsCall{Call: call}
}

// MockAttestationsServiceInterfaceListAttestationsCall wrap *gomock.Call
type MockAttestationsServiceInterfaceListAttestationsCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockAttestationsServiceInterfaceListAttestationsCall) Return(arg0 []*gitlab.Attestation, arg1 *gitlab.Response, arg2 error) *MockAttestationsServiceInterfaceListAttestationsCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockAttestationsServiceInterfaceListAttestationsCall) Do(f func(any, string, ...gitlab.RequestOptionFunc) ([]*gitlab.Attestation, *gitlab.Response, error)) *MockAttestationsServiceInterfaceListAttestationsCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockAttestationsServiceInterfaceListAttestationsCall) DoAndReturn(f func(any, string, ...gitlab.RequestOptionFunc) ([]*gitlab.Attestation, *gitlab.Response, error)) *MockAttestationsServiceInterfaceListAttestationsCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}
