// Code generated by MockGen. DO NOT EDIT.
// Source: gitlab.com/gitlab-org/api/client-go/v2 (interfaces: WorkItemsServiceInterface)
//
// Generated by this command:
//
//	mockgen -typed -destination=workitems_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 WorkItemsServiceInterface
//

package testing

import (
	reflect "reflect"

	gitlab "gitlab.com/gitlab-org/api/client-go/v2"
	gomock "go.uber.org/mock/gomock"
)

// MockWorkItemsServiceInterface is a mock of WorkItemsServiceInterface interface.
type MockWorkItemsServiceInterface struct {
	ctrl     *gomock.Controller
	recorder *MockWorkItemsServiceInterfaceMockRecorder
	isgomock struct{}
}

// MockWorkItemsServiceInterfaceMockRecorder is the mock recorder for MockWorkItemsServiceInterface.
type MockWorkItemsServiceInterfaceMockRecorder struct {
	mock *MockWorkItemsServiceInterface
}

// NewMockWorkItemsServiceInterface creates a new mock instance.
func NewMockWorkItemsServiceInterface(ctrl *gomock.Controller) *MockWorkItemsServiceInterface {
	mock := &MockWorkItemsServiceInterface{ctrl: ctrl}
	mock.recorder = &MockWorkItemsServiceInterfaceMockRecorder{mock}
	return mock
}

// EXPECT returns an object that allows the caller to indicate expected use.
func (m *MockWorkItemsServiceInterface) EXPECT() *MockWorkItemsServiceInterfaceMockRecorder {
	return m.recorder
}

// CreateWorkItem mocks base method.
func (m *MockWorkItemsServiceInterface) CreateWorkItem(fullPath string, workItemTypeID gitlab.WorkItemTypeID, opt *gitlab.CreateWorkItemOptions, options ...gitlab.RequestOptionFunc) (*gitlab.WorkItem, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{fullPath, workItemTypeID, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "CreateWorkItem", varargs...)
	ret0, _ := ret[0].(*gitlab.WorkItem)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// CreateWorkItem indicates an expected call of CreateWorkItem.
func (mr *MockWorkItemsServiceInterfaceMockRecorder) CreateWorkItem(fullPath, workItemTypeID, opt any, options ...any) *MockWorkItemsServiceInterfaceCreateWorkItemCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{fullPath, workItemTypeID, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "CreateWorkItem", reflect.TypeOf((*MockWorkItemsServiceInterface)(nil).CreateWorkItem), varargs...)
	return &MockWorkItemsServiceInterfaceCreateWorkItemCall{Call: call}
}

// MockWorkItemsServiceInterfaceCreateWorkItemCall wrap *gomock.Call
type MockWorkItemsServiceInterfaceCreateWorkItemCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockWorkItemsServiceInterfaceCreateWorkItemCall) Return(arg0 *gitlab.WorkItem, arg1 *gitlab.Response, arg2 error) *MockWorkItemsServiceInterfaceCreateWorkItemCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockWorkItemsServiceInterfaceCreateWorkItemCall) Do(f func(string, gitlab.WorkItemTypeID, *gitlab.CreateWorkItemOptions, ...gitlab.RequestOptionFunc) (*gitlab.WorkItem, *gitlab.Response, error)) *MockWorkItemsServiceInterfaceCreateWorkItemCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockWorkItemsServiceInterfaceCreateWorkItemCall) DoAndReturn(f func(string, gitlab.WorkItemTypeID, *gitlab.CreateWorkItemOptions, ...gitlab.RequestOptionFunc) (*gitlab.WorkItem, *gitlab.Response, error)) *MockWorkItemsServiceInterfaceCreateWorkItemCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// DeleteWorkItem mocks base method.
func (m *MockWorkItemsServiceInterface) DeleteWorkItem(fullPath string, iid int64, options ...gitlab.RequestOptionFunc) (*gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{fullPath, iid}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "DeleteWorkItem", varargs...)
	ret0, _ := ret[0].(*gitlab.Response)
	ret1, _ := ret[1].(error)
	return ret0, ret1
}

// DeleteWorkItem indicates an expected call of DeleteWorkItem.
func (mr *MockWorkItemsServiceInterfaceMockRecorder) DeleteWorkItem(fullPath, iid any, options ...any) *MockWorkItemsServiceInterfaceDeleteWorkItemCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{fullPath, iid}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "DeleteWorkItem", reflect.TypeOf((*MockWorkItemsServiceInterface)(nil).DeleteWorkItem), varargs...)
	return &MockWorkItemsServiceInterfaceDeleteWorkItemCall{Call: call}
}

// MockWorkItemsServiceInterfaceDeleteWorkItemCall wrap *gomock.Call
type MockWorkItemsServiceInterfaceDeleteWorkItemCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockWorkItemsServiceInterfaceDeleteWorkItemCall) Return(arg0 *gitlab.Response, arg1 error) *MockWorkItemsServiceInterfaceDeleteWorkItemCall {
	c.Call = c.Call.Return(arg0, arg1)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockWorkItemsServiceInterfaceDeleteWorkItemCall) Do(f func(string, int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockWorkItemsServiceInterfaceDeleteWorkItemCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockWorkItemsServiceInterfaceDeleteWorkItemCall) DoAndReturn(f func(string, int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockWorkItemsServiceInterfaceDeleteWorkItemCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// GetWorkItem mocks base method.
func (m *MockWorkItemsServiceInterface) GetWorkItem(fullPath string, iid int64, options ...gitlab.RequestOptionFunc) (*gitlab.WorkItem, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{fullPath, iid}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "GetWorkItem", varargs...)
	ret0, _ := ret[0].(*gitlab.WorkItem)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// GetWorkItem indicates an expected call of GetWorkItem.
func (mr *MockWorkItemsServiceInterfaceMockRecorder) GetWorkItem(fullPath, iid any, options ...any) *MockWorkItemsServiceInterfaceGetWorkItemCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{fullPath, iid}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "GetWorkItem", reflect.TypeOf((*MockWorkItemsServiceInterface)(nil).GetWorkItem), varargs...)
	return &MockWorkItemsServiceInterfaceGetWorkItemCall{Call: call}
}

// MockWorkItemsServiceInterfaceGetWorkItemCall wrap *gomock.Call
type MockWorkItemsServiceInterfaceGetWorkItemCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockWorkItemsServiceInterfaceGetWorkItemCall) Return(arg0 *gitlab.WorkItem, arg1 *gitlab.Response, arg2 error) *MockWorkItemsServiceInterfaceGetWorkItemCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockWorkItemsServiceInterfaceGetWorkItemCall) Do(f func(string, int64, ...gitlab.RequestOptionFunc) (*gitlab.WorkItem, *gitlab.Response, error)) *MockWorkItemsServiceInterfaceGetWorkItemCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockWorkItemsServiceInterfaceGetWorkItemCall) DoAndReturn(f func(string, int64, ...gitlab.RequestOptionFunc) (*gitlab.WorkItem, *gitlab.Response, error)) *MockWorkItemsServiceInterfaceGetWorkItemCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// ListWorkItems mocks base method.
func (m *MockWorkItemsServiceInterface) ListWorkItems(fullPath string, opt *gitlab.ListWorkItemsOptions, options ...gitlab.RequestOptionFunc) ([]*gitlab.WorkItem, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{fullPath, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "ListWorkItems", varargs...)
	ret0, _ := ret[0].([]*gitlab.WorkItem)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// ListWorkItems indicates an expected call of ListWorkItems.
func (mr *MockWorkItemsServiceInterfaceMockRecorder) ListWorkItems(fullPath, opt any, options ...any) *MockWorkItemsServiceInterfaceListWorkItemsCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{fullPath, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "ListWorkItems", reflect.TypeOf((*MockWorkItemsServiceInterface)(nil).ListWorkItems), varargs...)
	return &MockWorkItemsServiceInterfaceListWorkItemsCall{Call: call}
}

// MockWorkItemsServiceInterfaceListWorkItemsCall wrap *gomock.Call
type MockWorkItemsServiceInterfaceListWorkItemsCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockWorkItemsServiceInterfaceListWorkItemsCall) Return(arg0 []*gitlab.WorkItem, arg1 *gitlab.Response, arg2 error) *MockWorkItemsServiceInterfaceListWorkItemsCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockWorkItemsServiceInterfaceListWorkItemsCall) Do(f func(string, *gitlab.ListWorkItemsOptions, ...gitlab.RequestOptionFunc) ([]*gitlab.WorkItem, *gitlab.Response, error)) *MockWorkItemsServiceInterfaceListWorkItemsCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockWorkItemsServiceInterfaceListWorkItemsCall) DoAndReturn(f func(string, *gitlab.ListWorkItemsOptions, ...gitlab.RequestOptionFunc) ([]*gitlab.WorkItem, *gitlab.Response, error)) *MockWorkItemsServiceInterfaceListWorkItemsCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// UpdateWorkItem mocks base method.
func (m *MockWorkItemsServiceInterface) UpdateWorkItem(fullPath string, iid int64, opt *gitlab.UpdateWorkItemOptions, options ...gitlab.RequestOptionFunc) (*gitlab.WorkItem, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{fullPath, iid, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "UpdateWorkItem", varargs...)
	ret0, _ := ret[0].(*gitlab.WorkItem)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// UpdateWorkItem indicates an expected call of UpdateWorkItem.
func (mr *MockWorkItemsServiceInterfaceMockRecorder) UpdateWorkItem(fullPath, iid, opt any, options ...any) *MockWorkItemsServiceInterfaceUpdateWorkItemCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{fullPath, iid, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "UpdateWorkItem", reflect.TypeOf((*MockWorkItemsServiceInterface)(nil).UpdateWorkItem), varargs...)
	return &MockWorkItemsServiceInterfaceUpdateWorkItemCall{Call: call}
}

// MockWorkItemsServiceInterfaceUpdateWorkItemCall wrap *gomock.Call
type MockWorkItemsServiceInterfaceUpdateWorkItemCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockWorkItemsServiceInterfaceUpdateWorkItemCall) Return(arg0 *gitlab.WorkItem, arg1 *gitlab.Response, arg2 error) *MockWorkItemsServiceInterfaceUpdateWorkItemCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockWorkItemsServiceInterfaceUpdateWorkItemCall) Do(f func(string, int64, *gitlab.UpdateWorkItemOptions, ...gitlab.RequestOptionFunc) (*gitlab.WorkItem, *gitlab.Response, error)) *MockWorkItemsServiceInterfaceUpdateWorkItemCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockWorkItemsServiceInterfaceUpdateWorkItemCall) DoAndReturn(f func(string, int64, *gitlab.UpdateWorkItemOptions, ...gitlab.RequestOptionFunc) (*gitlab.WorkItem, *gitlab.Response, error)) *MockWorkItemsServiceInterfaceUpdateWorkItemCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}
