// Code generated by MockGen. DO NOT EDIT.
// Source: gitlab.com/gitlab-org/api/client-go/v2 (interfaces: AdminCompliancePolicySettingsServiceInterface)
//
// Generated by this command:
//
//	mockgen -typed -destination=admin_compliance_policy_settings_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 AdminCompliancePolicySettingsServiceInterface
//

package testing

import (
	reflect "reflect"

	gitlab "gitlab.com/gitlab-org/api/client-go/v2"
	gomock "go.uber.org/mock/gomock"
)

// MockAdminCompliancePolicySettingsServiceInterface is a mock of AdminCompliancePolicySettingsServiceInterface interface.
type MockAdminCompliancePolicySettingsServiceInterface struct {
	ctrl     *gomock.Controller
	recorder *MockAdminCompliancePolicySettingsServiceInterfaceMockRecorder
	isgomock struct{}
}

// MockAdminCompliancePolicySettingsServiceInterfaceMockRecorder is the mock recorder for MockAdminCompliancePolicySettingsServiceInterface.
type MockAdminCompliancePolicySettingsServiceInterfaceMockRecorder struct {
	mock *MockAdminCompliancePolicySettingsServiceInterface
}

// NewMockAdminCompliancePolicySettingsServiceInterface creates a new mock instance.
func NewMockAdminCompliancePolicySettingsServiceInterface(ctrl *gomock.Controller) *MockAdminCompliancePolicySettingsServiceInterface {
	mock := &MockAdminCompliancePolicySettingsServiceInterface{ctrl: ctrl}
	mock.recorder = &MockAdminCompliancePolicySettingsServiceInterfaceMockRecorder{mock}
	return mock
}

// EXPECT returns an object that allows the caller to indicate expected use.
func (m *MockAdminCompliancePolicySettingsServiceInterface) EXPECT() *MockAdminCompliancePolicySettingsServiceInterfaceMockRecorder {
	return m.recorder
}

// GetCompliancePolicySettings mocks base method.
func (m *MockAdminCompliancePolicySettingsServiceInterface) GetCompliancePolicySettings(options ...gitlab.RequestOptionFunc) (*gitlab.AdminCompliancePolicySettings, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "GetCompliancePolicySettings", varargs...)
	ret0, _ := ret[0].(*gitlab.AdminCompliancePolicySettings)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// GetCompliancePolicySettings indicates an expected call of GetCompliancePolicySettings.
func (mr *MockAdminCompliancePolicySettingsServiceInterfaceMockRecorder) GetCompliancePolicySettings(options ...any) *MockAdminCompliancePolicySettingsServiceInterfaceGetCompliancePolicySettingsCall {
	mr.mock.ctrl.T.Helper()
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "GetCompliancePolicySettings", reflect.TypeOf((*MockAdminCompliancePolicySettingsServiceInterface)(nil).GetCompliancePolicySettings), options...)
	return &MockAdminCompliancePolicySettingsServiceInterfaceGetCompliancePolicySettingsCall{Call: call}
}

// MockAdminCompliancePolicySettingsServiceInterfaceGetCompliancePolicySettingsCall wrap *gomock.Call
type MockAdminCompliancePolicySettingsServiceInterfaceGetCompliancePolicySettingsCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockAdminCompliancePolicySettingsServiceInterfaceGetCompliancePolicySettingsCall) Return(arg0 *gitlab.AdminCompliancePolicySettings, arg1 *gitlab.Response, arg2 error) *MockAdminCompliancePolicySettingsServiceInterfaceGetCompliancePolicySettingsCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockAdminCompliancePolicySettingsServiceInterfaceGetCompliancePolicySettingsCall) Do(f func(...gitlab.RequestOptionFunc) (*gitlab.AdminCompliancePolicySettings, *gitlab.Response, error)) *MockAdminCompliancePolicySettingsServiceInterfaceGetCompliancePolicySettingsCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockAdminCompliancePolicySettingsServiceInterfaceGetCompliancePolicySettingsCall) DoAndReturn(f func(...gitlab.RequestOptionFunc) (*gitlab.AdminCompliancePolicySettings, *gitlab.Response, error)) *MockAdminCompliancePolicySettingsServiceInterfaceGetCompliancePolicySettingsCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// UpdateCompliancePolicySettings mocks base method.
func (m *MockAdminCompliancePolicySettingsServiceInterface) UpdateCompliancePolicySettings(opt *gitlab.UpdateAdminCompliancePolicySettingsOptions, options ...gitlab.RequestOptionFunc) (*gitlab.AdminCompliancePolicySettings, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "UpdateCompliancePolicySettings", varargs...)
	ret0, _ := ret[0].(*gitlab.AdminCompliancePolicySettings)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// UpdateCompliancePolicySettings indicates an expected call of UpdateCompliancePolicySettings.
func (mr *MockAdminCompliancePolicySettingsServiceInterfaceMockRecorder) UpdateCompliancePolicySettings(opt any, options ...any) *MockAdminCompliancePolicySettingsServiceInterfaceUpdateCompliancePolicySettingsCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "UpdateCompliancePolicySettings", reflect.TypeOf((*MockAdminCompliancePolicySettingsServiceInterface)(nil).UpdateCompliancePolicySettings), varargs...)
	return &MockAdminCompliancePolicySettingsServiceInterfaceUpdateCompliancePolicySettingsCall{Call: call}
}

// MockAdminCompliancePolicySettingsServiceInterfaceUpdateCompliancePolicySettingsCall wrap *gomock.Call
type MockAdminCompliancePolicySettingsServiceInterfaceUpdateCompliancePolicySettingsCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockAdminCompliancePolicySettingsServiceInterfaceUpdateCompliancePolicySettingsCall) Return(arg0 *gitlab.AdminCompliancePolicySettings, arg1 *gitlab.Response, arg2 error) *MockAdminCompliancePolicySettingsServiceInterfaceUpdateCompliancePolicySettingsCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockAdminCompliancePolicySettingsServiceInterfaceUpdateCompliancePolicySettingsCall) Do(f func(*gitlab.UpdateAdminCompliancePolicySettingsOptions, ...gitlab.RequestOptionFunc) (*gitlab.AdminCompliancePolicySettings, *gitlab.Response, error)) *MockAdminCompliancePolicySettingsServiceInterfaceUpdateCompliancePolicySettingsCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockAdminCompliancePolicySettingsServiceInterfaceUpdateCompliancePolicySettingsCall) DoAndReturn(f func(*gitlab.UpdateAdminCompliancePolicySettingsOptions, ...gitlab.RequestOptionFunc) (*gitlab.AdminCompliancePolicySettings, *gitlab.Response, error)) *MockAdminCompliancePolicySettingsServiceInterfaceUpdateCompliancePolicySettingsCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}
