// Code generated by scripts/generate_mock_api.sh. DO NOT EDIT.

package testing

//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=access_requests_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 AccessRequestsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=admin_compliance_policy_settings_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 AdminCompliancePolicySettingsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=alert_management_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 AlertManagementServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=appearance_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 AppearanceServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=application_statistics_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ApplicationStatisticsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=applications_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ApplicationsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=attestations_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 AttestationsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=audit_events_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 AuditEventsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=avatar_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 AvatarRequestsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=award_emojis_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 AwardEmojiServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=boards_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 IssueBoardsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=branches_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 BranchesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=broadcast_messages_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 BroadcastMessagesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=bulk_imports_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 BulkImportsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=ci_yml_templates_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 CIYMLTemplatesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=cluster_agents_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ClusterAgentsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=commits_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 CommitsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=container_registry_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ContainerRegistryServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=container_registry_protection_rules_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ContainerRegistryProtectionRulesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=custom_attributes_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 CustomAttributesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=database_migrations_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DatabaseMigrationsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=dependencies_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DependenciesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=dependency_list_export_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DependencyListExportServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=dependency_proxy_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DependencyProxyServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=deploy_keys_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DeployKeysServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=deploy_tokens_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DeployTokensServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=deployments_merge_requests_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DeploymentMergeRequestsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=deployments_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DeploymentsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=discussions_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DiscussionsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=dockerfile_templates_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DockerfileTemplatesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=dora_metrics_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DORAMetricsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=draft_notes_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 DraftNotesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=enterprise_users_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 EnterpriseUsersServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=environments_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 EnvironmentsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=epic_issues_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 EpicIssuesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=epics_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 EpicsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=error_tracking_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ErrorTrackingServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=events_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 EventsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=external_status_checks_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ExternalStatusChecksServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=feature_flag_user_lists_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 FeatureFlagUserListsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=feature_flags_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 FeaturesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=freeze_periods_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 FreezePeriodsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=generic_packages_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GenericPackagesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=geo_nodes_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GeoNodesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=geo_sites_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GeoSitesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=gitignore_templates_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GitIgnoreTemplatesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=graphql_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GraphQLInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_access_tokens_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupAccessTokensServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_activity_analytics_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupActivityAnalyticsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_badges_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupBadgesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_boards_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupIssueBoardsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_clusters_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupClustersServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_credentials_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupCredentialsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_epic_boards_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupEpicBoardsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_import_export_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupImportExportServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_iterations_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupIterationsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_labels_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupLabelsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_markdown_uploads_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupMarkdownUploadsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_members_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupMembersServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_milestones_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupMilestonesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_protected_branches_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupProtectedBranchesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_protected_environments_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupProtectedEnvironmentsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_relations_export_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupRelationsExportServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_releases_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupReleasesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_repository_storage_move_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupRepositoryStorageMoveServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_scim_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupSCIMServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_security_settings_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupSecuritySettingsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_ssh_certificates_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupSSHCertificatesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_variables_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupVariablesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=group_wikis_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupWikisServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=groups_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 GroupsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=import_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ImportServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=instance_clusters_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 InstanceClustersServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=instance_variables_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 InstanceVariablesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=integrations_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 IntegrationsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=invites_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 InvitesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=issue_links_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 IssueLinksServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=issues_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 IssuesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=issues_statistics_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 IssuesStatisticsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=job_token_scope_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 JobTokenScopeServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=jobs_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 JobsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=keys_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 KeysServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=labels_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 LabelsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=license_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 LicenseServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=license_templates_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 LicenseTemplatesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=markdown_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 MarkdownServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=member_roles_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 MemberRolesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=merge_request_approval_settings_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 MergeRequestApprovalSettingsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=merge_request_approvals_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 MergeRequestApprovalsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=merge_request_context_commits_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 MergeRequestContextCommitsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=merge_requests_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 MergeRequestsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=merge_trains_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 MergeTrainsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=metadata_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 MetadataServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=milestones_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 MilestonesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=model_registry_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ModelRegistryServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=namespaces_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 NamespacesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=notes_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 NotesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=notifications_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 NotificationSettingsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=orbit_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 OrbitServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=packages_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 PackagesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=pages_domains_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 PagesDomainsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=pages_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 PagesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=personal_access_tokens_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 PersonalAccessTokensServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=pipeline_schedules_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 PipelineSchedulesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=pipeline_triggers_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 PipelineTriggersServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=pipelines_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 PipelinesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=plan_limits_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 PlanLimitsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_access_tokens_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectAccessTokensServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_aliases_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectAliasesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_badges_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectBadgesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_clusters_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectClustersServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_feature_flags_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectFeatureFlagServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_import_export_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectImportExportServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_iterations_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectIterationsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_markdown_uploads_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectMarkdownUploadsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_members_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectMembersServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_mirror_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectMirrorServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_repository_storage_move_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectRepositoryStorageMoveServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_security_settings_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectSecuritySettingsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_snippets_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectSnippetsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_statistics_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectStatisticsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_templates_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectTemplatesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_variables_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectVariablesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=project_vulnerabilities_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectVulnerabilitiesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=projects_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProjectsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=protected_branches_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProtectedBranchesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=protected_environments_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProtectedEnvironmentsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=protected_packages_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProtectedPackagesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=protected_tags_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ProtectedTagsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=releaselinks_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ReleaseLinksServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=releases_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ReleasesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=repositories_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 RepositoriesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=repository_files_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 RepositoryFilesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=repository_submodules_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 RepositorySubmodulesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=resource_group_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ResourceGroupServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=resource_iteration_events_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ResourceIterationEventsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=resource_label_events_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ResourceLabelEventsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=resource_milestone_events_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ResourceMilestoneEventsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=resource_state_events_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ResourceStateEventsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=resource_weight_events_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ResourceWeightEventsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=runner_controller_scopes_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 RunnerControllerScopesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=runner_controller_tokens_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 RunnerControllerTokensServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=runner_controllers_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 RunnerControllersServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=runners_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 RunnersServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=search_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SearchServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=secure_files_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SecureFilesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=security_attributes_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SecurityAttributesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=security_categories_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SecurityCategoriesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=services_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ServicesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=settings_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SettingsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=sidekiq_metrics_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SidekiqServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=snippet_repository_storage_move_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SnippetRepositoryStorageMoveServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=snippets_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SnippetsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=system_hooks_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SystemHooksServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=tags_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 TagsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=terraform_states_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 TerraformStatesServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=todos_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 TodosServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=topics_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 TopicsServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=usage_data_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 UsageDataServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=users_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 UsersServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=validate_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 ValidateServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=version_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 VersionServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=wikis_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 WikisServiceInterface
//go:generate go run go.uber.org/mock/mockgen@v0.6.0 -typed -destination=workitems_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 WorkItemsServiceInterface
