package d2themescatalog

import "oss.terrastruct.com/d2/d2themes"

var GrapeSoda = d2themes.Theme{
	ID:   6,
	Name: "Grape Soda",
	Colors: d2themes.ColorPalette{
		Neutrals: d2themes.CoolNeutral,

		B1: "#170034",
		B2: "#7639C5",
		B3: "#8F70D1",
		B4: "#C1A2F3",
		B5: "#DACEFB",
		B6: "#F2EDFF",

		AA2: "#0F66B7",
		AA4: "#87BFF3",
		AA5: "#BCDDFB",

		AB4: "#EA99C6",
		AB5: "#FFDAEF",
	},
}
