// Code generated by MockGen. DO NOT EDIT.
// Source: gitlab.com/gitlab-org/api/client-go/v2 (interfaces: OrbitServiceInterface)
//
// Generated by this command:
//
//	mockgen -typed -destination=orbit_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 OrbitServiceInterface
//

package testing

import (
	io "io"
	reflect "reflect"

	gitlab "gitlab.com/gitlab-org/api/client-go/v2"
	gomock "go.uber.org/mock/gomock"
)

// MockOrbitServiceInterface is a mock of OrbitServiceInterface interface.
type MockOrbitServiceInterface struct {
	ctrl     *gomock.Controller
	recorder *MockOrbitServiceInterfaceMockRecorder
	isgomock struct{}
}

// MockOrbitServiceInterfaceMockRecorder is the mock recorder for MockOrbitServiceInterface.
type MockOrbitServiceInterfaceMockRecorder struct {
	mock *MockOrbitServiceInterface
}

// NewMockOrbitServiceInterface creates a new mock instance.
func NewMockOrbitServiceInterface(ctrl *gomock.Controller) *MockOrbitServiceInterface {
	mock := &MockOrbitServiceInterface{ctrl: ctrl}
	mock.recorder = &MockOrbitServiceInterfaceMockRecorder{mock}
	return mock
}

// EXPECT returns an object that allows the caller to indicate expected use.
func (m *MockOrbitServiceInterface) EXPECT() *MockOrbitServiceInterfaceMockRecorder {
	return m.recorder
}

// GetDsl mocks base method.
func (m *MockOrbitServiceInterface) GetDsl(opt *gitlab.GetOrbitDslOptions, options ...gitlab.RequestOptionFunc) (string, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "GetDsl", varargs...)
	ret0, _ := ret[0].(string)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// GetDsl indicates an expected call of GetDsl.
func (mr *MockOrbitServiceInterfaceMockRecorder) GetDsl(opt any, options ...any) *MockOrbitServiceInterfaceGetDslCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "GetDsl", reflect.TypeOf((*MockOrbitServiceInterface)(nil).GetDsl), varargs...)
	return &MockOrbitServiceInterfaceGetDslCall{Call: call}
}

// MockOrbitServiceInterfaceGetDslCall wrap *gomock.Call
type MockOrbitServiceInterfaceGetDslCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockOrbitServiceInterfaceGetDslCall) Return(arg0 string, arg1 *gitlab.Response, arg2 error) *MockOrbitServiceInterfaceGetDslCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockOrbitServiceInterfaceGetDslCall) Do(f func(*gitlab.GetOrbitDslOptions, ...gitlab.RequestOptionFunc) (string, *gitlab.Response, error)) *MockOrbitServiceInterfaceGetDslCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockOrbitServiceInterfaceGetDslCall) DoAndReturn(f func(*gitlab.GetOrbitDslOptions, ...gitlab.RequestOptionFunc) (string, *gitlab.Response, error)) *MockOrbitServiceInterfaceGetDslCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// GetGraphStatus mocks base method.
func (m *MockOrbitServiceInterface) GetGraphStatus(opt *gitlab.GetGraphStatusOptions, options ...gitlab.RequestOptionFunc) (*gitlab.OrbitGraphStatus, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "GetGraphStatus", varargs...)
	ret0, _ := ret[0].(*gitlab.OrbitGraphStatus)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// GetGraphStatus indicates an expected call of GetGraphStatus.
func (mr *MockOrbitServiceInterfaceMockRecorder) GetGraphStatus(opt any, options ...any) *MockOrbitServiceInterfaceGetGraphStatusCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "GetGraphStatus", reflect.TypeOf((*MockOrbitServiceInterface)(nil).GetGraphStatus), varargs...)
	return &MockOrbitServiceInterfaceGetGraphStatusCall{Call: call}
}

// MockOrbitServiceInterfaceGetGraphStatusCall wrap *gomock.Call
type MockOrbitServiceInterfaceGetGraphStatusCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockOrbitServiceInterfaceGetGraphStatusCall) Return(arg0 *gitlab.OrbitGraphStatus, arg1 *gitlab.Response, arg2 error) *MockOrbitServiceInterfaceGetGraphStatusCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockOrbitServiceInterfaceGetGraphStatusCall) Do(f func(*gitlab.GetGraphStatusOptions, ...gitlab.RequestOptionFunc) (*gitlab.OrbitGraphStatus, *gitlab.Response, error)) *MockOrbitServiceInterfaceGetGraphStatusCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockOrbitServiceInterfaceGetGraphStatusCall) DoAndReturn(f func(*gitlab.GetGraphStatusOptions, ...gitlab.RequestOptionFunc) (*gitlab.OrbitGraphStatus, *gitlab.Response, error)) *MockOrbitServiceInterfaceGetGraphStatusCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// GetSchema mocks base method.
func (m *MockOrbitServiceInterface) GetSchema(opt *gitlab.GetOrbitSchemaOptions, options ...gitlab.RequestOptionFunc) (*gitlab.OrbitSchema, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "GetSchema", varargs...)
	ret0, _ := ret[0].(*gitlab.OrbitSchema)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// GetSchema indicates an expected call of GetSchema.
func (mr *MockOrbitServiceInterfaceMockRecorder) GetSchema(opt any, options ...any) *MockOrbitServiceInterfaceGetSchemaCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "GetSchema", reflect.TypeOf((*MockOrbitServiceInterface)(nil).GetSchema), varargs...)
	return &MockOrbitServiceInterfaceGetSchemaCall{Call: call}
}

// MockOrbitServiceInterfaceGetSchemaCall wrap *gomock.Call
type MockOrbitServiceInterfaceGetSchemaCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockOrbitServiceInterfaceGetSchemaCall) Return(arg0 *gitlab.OrbitSchema, arg1 *gitlab.Response, arg2 error) *MockOrbitServiceInterfaceGetSchemaCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockOrbitServiceInterfaceGetSchemaCall) Do(f func(*gitlab.GetOrbitSchemaOptions, ...gitlab.RequestOptionFunc) (*gitlab.OrbitSchema, *gitlab.Response, error)) *MockOrbitServiceInterfaceGetSchemaCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockOrbitServiceInterfaceGetSchemaCall) DoAndReturn(f func(*gitlab.GetOrbitSchemaOptions, ...gitlab.RequestOptionFunc) (*gitlab.OrbitSchema, *gitlab.Response, error)) *MockOrbitServiceInterfaceGetSchemaCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// GetStatus mocks base method.
func (m *MockOrbitServiceInterface) GetStatus(opt *gitlab.GetOrbitStatusOptions, options ...gitlab.RequestOptionFunc) (*gitlab.OrbitStatus, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "GetStatus", varargs...)
	ret0, _ := ret[0].(*gitlab.OrbitStatus)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// GetStatus indicates an expected call of GetStatus.
func (mr *MockOrbitServiceInterfaceMockRecorder) GetStatus(opt any, options ...any) *MockOrbitServiceInterfaceGetStatusCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "GetStatus", reflect.TypeOf((*MockOrbitServiceInterface)(nil).GetStatus), varargs...)
	return &MockOrbitServiceInterfaceGetStatusCall{Call: call}
}

// MockOrbitServiceInterfaceGetStatusCall wrap *gomock.Call
type MockOrbitServiceInterfaceGetStatusCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockOrbitServiceInterfaceGetStatusCall) Return(arg0 *gitlab.OrbitStatus, arg1 *gitlab.Response, arg2 error) *MockOrbitServiceInterfaceGetStatusCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockOrbitServiceInterfaceGetStatusCall) Do(f func(*gitlab.GetOrbitStatusOptions, ...gitlab.RequestOptionFunc) (*gitlab.OrbitStatus, *gitlab.Response, error)) *MockOrbitServiceInterfaceGetStatusCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockOrbitServiceInterfaceGetStatusCall) DoAndReturn(f func(*gitlab.GetOrbitStatusOptions, ...gitlab.RequestOptionFunc) (*gitlab.OrbitStatus, *gitlab.Response, error)) *MockOrbitServiceInterfaceGetStatusCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// GetTools mocks base method.
func (m *MockOrbitServiceInterface) GetTools(options ...gitlab.RequestOptionFunc) (*gitlab.OrbitTools, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "GetTools", varargs...)
	ret0, _ := ret[0].(*gitlab.OrbitTools)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// GetTools indicates an expected call of GetTools.
func (mr *MockOrbitServiceInterfaceMockRecorder) GetTools(options ...any) *MockOrbitServiceInterfaceGetToolsCall {
	mr.mock.ctrl.T.Helper()
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "GetTools", reflect.TypeOf((*MockOrbitServiceInterface)(nil).GetTools), options...)
	return &MockOrbitServiceInterfaceGetToolsCall{Call: call}
}

// MockOrbitServiceInterfaceGetToolsCall wrap *gomock.Call
type MockOrbitServiceInterfaceGetToolsCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockOrbitServiceInterfaceGetToolsCall) Return(arg0 *gitlab.OrbitTools, arg1 *gitlab.Response, arg2 error) *MockOrbitServiceInterfaceGetToolsCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockOrbitServiceInterfaceGetToolsCall) Do(f func(...gitlab.RequestOptionFunc) (*gitlab.OrbitTools, *gitlab.Response, error)) *MockOrbitServiceInterfaceGetToolsCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockOrbitServiceInterfaceGetToolsCall) DoAndReturn(f func(...gitlab.RequestOptionFunc) (*gitlab.OrbitTools, *gitlab.Response, error)) *MockOrbitServiceInterfaceGetToolsCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// Query mocks base method.
func (m *MockOrbitServiceInterface) Query(opt *gitlab.OrbitQueryRequest, options ...gitlab.RequestOptionFunc) (*gitlab.OrbitQueryResult, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "Query", varargs...)
	ret0, _ := ret[0].(*gitlab.OrbitQueryResult)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// Query indicates an expected call of Query.
func (mr *MockOrbitServiceInterfaceMockRecorder) Query(opt any, options ...any) *MockOrbitServiceInterfaceQueryCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "Query", reflect.TypeOf((*MockOrbitServiceInterface)(nil).Query), varargs...)
	return &MockOrbitServiceInterfaceQueryCall{Call: call}
}

// MockOrbitServiceInterfaceQueryCall wrap *gomock.Call
type MockOrbitServiceInterfaceQueryCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockOrbitServiceInterfaceQueryCall) Return(arg0 *gitlab.OrbitQueryResult, arg1 *gitlab.Response, arg2 error) *MockOrbitServiceInterfaceQueryCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockOrbitServiceInterfaceQueryCall) Do(f func(*gitlab.OrbitQueryRequest, ...gitlab.RequestOptionFunc) (*gitlab.OrbitQueryResult, *gitlab.Response, error)) *MockOrbitServiceInterfaceQueryCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockOrbitServiceInterfaceQueryCall) DoAndReturn(f func(*gitlab.OrbitQueryRequest, ...gitlab.RequestOptionFunc) (*gitlab.OrbitQueryResult, *gitlab.Response, error)) *MockOrbitServiceInterfaceQueryCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// QueryRaw mocks base method.
func (m *MockOrbitServiceInterface) QueryRaw(opt *gitlab.OrbitQueryRequest, w io.Writer, options ...gitlab.RequestOptionFunc) (*gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{opt, w}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "QueryRaw", varargs...)
	ret0, _ := ret[0].(*gitlab.Response)
	ret1, _ := ret[1].(error)
	return ret0, ret1
}

// QueryRaw indicates an expected call of QueryRaw.
func (mr *MockOrbitServiceInterfaceMockRecorder) QueryRaw(opt, w any, options ...any) *MockOrbitServiceInterfaceQueryRawCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{opt, w}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "QueryRaw", reflect.TypeOf((*MockOrbitServiceInterface)(nil).QueryRaw), varargs...)
	return &MockOrbitServiceInterfaceQueryRawCall{Call: call}
}

// MockOrbitServiceInterfaceQueryRawCall wrap *gomock.Call
type MockOrbitServiceInterfaceQueryRawCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockOrbitServiceInterfaceQueryRawCall) Return(arg0 *gitlab.Response, arg1 error) *MockOrbitServiceInterfaceQueryRawCall {
	c.Call = c.Call.Return(arg0, arg1)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockOrbitServiceInterfaceQueryRawCall) Do(f func(*gitlab.OrbitQueryRequest, io.Writer, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockOrbitServiceInterfaceQueryRawCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockOrbitServiceInterfaceQueryRawCall) DoAndReturn(f func(*gitlab.OrbitQueryRequest, io.Writer, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockOrbitServiceInterfaceQueryRawCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}
