// Code generated by MockGen. DO NOT EDIT.
// Source: gitlab.com/gitlab-org/api/client-go/v2 (interfaces: RunnerControllerScopesServiceInterface)
//
// Generated by this command:
//
//	mockgen -typed -destination=runner_controller_scopes_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 RunnerControllerScopesServiceInterface
//

package testing

import (
	reflect "reflect"

	gitlab "gitlab.com/gitlab-org/api/client-go/v2"
	gomock "go.uber.org/mock/gomock"
)

// MockRunnerControllerScopesServiceInterface is a mock of RunnerControllerScopesServiceInterface interface.
type MockRunnerControllerScopesServiceInterface struct {
	ctrl     *gomock.Controller
	recorder *MockRunnerControllerScopesServiceInterfaceMockRecorder
	isgomock struct{}
}

// MockRunnerControllerScopesServiceInterfaceMockRecorder is the mock recorder for MockRunnerControllerScopesServiceInterface.
type MockRunnerControllerScopesServiceInterfaceMockRecorder struct {
	mock *MockRunnerControllerScopesServiceInterface
}

// NewMockRunnerControllerScopesServiceInterface creates a new mock instance.
func NewMockRunnerControllerScopesServiceInterface(ctrl *gomock.Controller) *MockRunnerControllerScopesServiceInterface {
	mock := &MockRunnerControllerScopesServiceInterface{ctrl: ctrl}
	mock.recorder = &MockRunnerControllerScopesServiceInterfaceMockRecorder{mock}
	return mock
}

// EXPECT returns an object that allows the caller to indicate expected use.
func (m *MockRunnerControllerScopesServiceInterface) EXPECT() *MockRunnerControllerScopesServiceInterfaceMockRecorder {
	return m.recorder
}

// AddRunnerControllerInstanceScope mocks base method.
func (m *MockRunnerControllerScopesServiceInterface) AddRunnerControllerInstanceScope(rid int64, options ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerInstanceLevelScoping, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "AddRunnerControllerInstanceScope", varargs...)
	ret0, _ := ret[0].(*gitlab.RunnerControllerInstanceLevelScoping)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// AddRunnerControllerInstanceScope indicates an expected call of AddRunnerControllerInstanceScope.
func (mr *MockRunnerControllerScopesServiceInterfaceMockRecorder) AddRunnerControllerInstanceScope(rid any, options ...any) *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerInstanceScopeCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "AddRunnerControllerInstanceScope", reflect.TypeOf((*MockRunnerControllerScopesServiceInterface)(nil).AddRunnerControllerInstanceScope), varargs...)
	return &MockRunnerControllerScopesServiceInterfaceAddRunnerControllerInstanceScopeCall{Call: call}
}

// MockRunnerControllerScopesServiceInterfaceAddRunnerControllerInstanceScopeCall wrap *gomock.Call
type MockRunnerControllerScopesServiceInterfaceAddRunnerControllerInstanceScopeCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerInstanceScopeCall) Return(arg0 *gitlab.RunnerControllerInstanceLevelScoping, arg1 *gitlab.Response, arg2 error) *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerInstanceScopeCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerInstanceScopeCall) Do(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerInstanceLevelScoping, *gitlab.Response, error)) *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerInstanceScopeCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerInstanceScopeCall) DoAndReturn(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerInstanceLevelScoping, *gitlab.Response, error)) *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerInstanceScopeCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// AddRunnerControllerRunnerScope mocks base method.
func (m *MockRunnerControllerScopesServiceInterface) AddRunnerControllerRunnerScope(rid, runnerID int64, options ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerRunnerLevelScoping, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid, runnerID}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "AddRunnerControllerRunnerScope", varargs...)
	ret0, _ := ret[0].(*gitlab.RunnerControllerRunnerLevelScoping)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// AddRunnerControllerRunnerScope indicates an expected call of AddRunnerControllerRunnerScope.
func (mr *MockRunnerControllerScopesServiceInterfaceMockRecorder) AddRunnerControllerRunnerScope(rid, runnerID any, options ...any) *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerRunnerScopeCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid, runnerID}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "AddRunnerControllerRunnerScope", reflect.TypeOf((*MockRunnerControllerScopesServiceInterface)(nil).AddRunnerControllerRunnerScope), varargs...)
	return &MockRunnerControllerScopesServiceInterfaceAddRunnerControllerRunnerScopeCall{Call: call}
}

// MockRunnerControllerScopesServiceInterfaceAddRunnerControllerRunnerScopeCall wrap *gomock.Call
type MockRunnerControllerScopesServiceInterfaceAddRunnerControllerRunnerScopeCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerRunnerScopeCall) Return(arg0 *gitlab.RunnerControllerRunnerLevelScoping, arg1 *gitlab.Response, arg2 error) *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerRunnerScopeCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerRunnerScopeCall) Do(f func(int64, int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerRunnerLevelScoping, *gitlab.Response, error)) *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerRunnerScopeCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerRunnerScopeCall) DoAndReturn(f func(int64, int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerRunnerLevelScoping, *gitlab.Response, error)) *MockRunnerControllerScopesServiceInterfaceAddRunnerControllerRunnerScopeCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// ListRunnerControllerScopes mocks base method.
func (m *MockRunnerControllerScopesServiceInterface) ListRunnerControllerScopes(rid int64, options ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerScopes, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "ListRunnerControllerScopes", varargs...)
	ret0, _ := ret[0].(*gitlab.RunnerControllerScopes)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// ListRunnerControllerScopes indicates an expected call of ListRunnerControllerScopes.
func (mr *MockRunnerControllerScopesServiceInterfaceMockRecorder) ListRunnerControllerScopes(rid any, options ...any) *MockRunnerControllerScopesServiceInterfaceListRunnerControllerScopesCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "ListRunnerControllerScopes", reflect.TypeOf((*MockRunnerControllerScopesServiceInterface)(nil).ListRunnerControllerScopes), varargs...)
	return &MockRunnerControllerScopesServiceInterfaceListRunnerControllerScopesCall{Call: call}
}

// MockRunnerControllerScopesServiceInterfaceListRunnerControllerScopesCall wrap *gomock.Call
type MockRunnerControllerScopesServiceInterfaceListRunnerControllerScopesCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllerScopesServiceInterfaceListRunnerControllerScopesCall) Return(arg0 *gitlab.RunnerControllerScopes, arg1 *gitlab.Response, arg2 error) *MockRunnerControllerScopesServiceInterfaceListRunnerControllerScopesCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllerScopesServiceInterfaceListRunnerControllerScopesCall) Do(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerScopes, *gitlab.Response, error)) *MockRunnerControllerScopesServiceInterfaceListRunnerControllerScopesCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllerScopesServiceInterfaceListRunnerControllerScopesCall) DoAndReturn(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.RunnerControllerScopes, *gitlab.Response, error)) *MockRunnerControllerScopesServiceInterfaceListRunnerControllerScopesCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// RemoveRunnerControllerInstanceScope mocks base method.
func (m *MockRunnerControllerScopesServiceInterface) RemoveRunnerControllerInstanceScope(rid int64, options ...gitlab.RequestOptionFunc) (*gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "RemoveRunnerControllerInstanceScope", varargs...)
	ret0, _ := ret[0].(*gitlab.Response)
	ret1, _ := ret[1].(error)
	return ret0, ret1
}

// RemoveRunnerControllerInstanceScope indicates an expected call of RemoveRunnerControllerInstanceScope.
func (mr *MockRunnerControllerScopesServiceInterfaceMockRecorder) RemoveRunnerControllerInstanceScope(rid any, options ...any) *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerInstanceScopeCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "RemoveRunnerControllerInstanceScope", reflect.TypeOf((*MockRunnerControllerScopesServiceInterface)(nil).RemoveRunnerControllerInstanceScope), varargs...)
	return &MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerInstanceScopeCall{Call: call}
}

// MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerInstanceScopeCall wrap *gomock.Call
type MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerInstanceScopeCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerInstanceScopeCall) Return(arg0 *gitlab.Response, arg1 error) *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerInstanceScopeCall {
	c.Call = c.Call.Return(arg0, arg1)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerInstanceScopeCall) Do(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerInstanceScopeCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerInstanceScopeCall) DoAndReturn(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerInstanceScopeCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// RemoveRunnerControllerRunnerScope mocks base method.
func (m *MockRunnerControllerScopesServiceInterface) RemoveRunnerControllerRunnerScope(rid, runnerID int64, options ...gitlab.RequestOptionFunc) (*gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{rid, runnerID}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "RemoveRunnerControllerRunnerScope", varargs...)
	ret0, _ := ret[0].(*gitlab.Response)
	ret1, _ := ret[1].(error)
	return ret0, ret1
}

// RemoveRunnerControllerRunnerScope indicates an expected call of RemoveRunnerControllerRunnerScope.
func (mr *MockRunnerControllerScopesServiceInterfaceMockRecorder) RemoveRunnerControllerRunnerScope(rid, runnerID any, options ...any) *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerRunnerScopeCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{rid, runnerID}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "RemoveRunnerControllerRunnerScope", reflect.TypeOf((*MockRunnerControllerScopesServiceInterface)(nil).RemoveRunnerControllerRunnerScope), varargs...)
	return &MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerRunnerScopeCall{Call: call}
}

// MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerRunnerScopeCall wrap *gomock.Call
type MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerRunnerScopeCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerRunnerScopeCall) Return(arg0 *gitlab.Response, arg1 error) *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerRunnerScopeCall {
	c.Call = c.Call.Return(arg0, arg1)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerRunnerScopeCall) Do(f func(int64, int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerRunnerScopeCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerRunnerScopeCall) DoAndReturn(f func(int64, int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockRunnerControllerScopesServiceInterfaceRemoveRunnerControllerRunnerScopeCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}
