// Code generated by MockGen. DO NOT EDIT.
// Source: gitlab.com/gitlab-org/api/client-go/v2 (interfaces: SecurityAttributesServiceInterface)
//
// Generated by this command:
//
//	mockgen -typed -destination=security_attributes_mock.go -write_package_comment=false -package=testing gitlab.com/gitlab-org/api/client-go/v2 SecurityAttributesServiceInterface
//

package testing

import (
	reflect "reflect"

	gitlab "gitlab.com/gitlab-org/api/client-go/v2"
	gomock "go.uber.org/mock/gomock"
)

// MockSecurityAttributesServiceInterface is a mock of SecurityAttributesServiceInterface interface.
type MockSecurityAttributesServiceInterface struct {
	ctrl     *gomock.Controller
	recorder *MockSecurityAttributesServiceInterfaceMockRecorder
	isgomock struct{}
}

// MockSecurityAttributesServiceInterfaceMockRecorder is the mock recorder for MockSecurityAttributesServiceInterface.
type MockSecurityAttributesServiceInterfaceMockRecorder struct {
	mock *MockSecurityAttributesServiceInterface
}

// NewMockSecurityAttributesServiceInterface creates a new mock instance.
func NewMockSecurityAttributesServiceInterface(ctrl *gomock.Controller) *MockSecurityAttributesServiceInterface {
	mock := &MockSecurityAttributesServiceInterface{ctrl: ctrl}
	mock.recorder = &MockSecurityAttributesServiceInterfaceMockRecorder{mock}
	return mock
}

// EXPECT returns an object that allows the caller to indicate expected use.
func (m *MockSecurityAttributesServiceInterface) EXPECT() *MockSecurityAttributesServiceInterfaceMockRecorder {
	return m.recorder
}

// BulkUpdateSecurityAttributes mocks base method.
func (m *MockSecurityAttributesServiceInterface) BulkUpdateSecurityAttributes(opt *gitlab.BulkUpdateSecurityAttributesOptions, options ...gitlab.RequestOptionFunc) (*gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "BulkUpdateSecurityAttributes", varargs...)
	ret0, _ := ret[0].(*gitlab.Response)
	ret1, _ := ret[1].(error)
	return ret0, ret1
}

// BulkUpdateSecurityAttributes indicates an expected call of BulkUpdateSecurityAttributes.
func (mr *MockSecurityAttributesServiceInterfaceMockRecorder) BulkUpdateSecurityAttributes(opt any, options ...any) *MockSecurityAttributesServiceInterfaceBulkUpdateSecurityAttributesCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "BulkUpdateSecurityAttributes", reflect.TypeOf((*MockSecurityAttributesServiceInterface)(nil).BulkUpdateSecurityAttributes), varargs...)
	return &MockSecurityAttributesServiceInterfaceBulkUpdateSecurityAttributesCall{Call: call}
}

// MockSecurityAttributesServiceInterfaceBulkUpdateSecurityAttributesCall wrap *gomock.Call
type MockSecurityAttributesServiceInterfaceBulkUpdateSecurityAttributesCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockSecurityAttributesServiceInterfaceBulkUpdateSecurityAttributesCall) Return(arg0 *gitlab.Response, arg1 error) *MockSecurityAttributesServiceInterfaceBulkUpdateSecurityAttributesCall {
	c.Call = c.Call.Return(arg0, arg1)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockSecurityAttributesServiceInterfaceBulkUpdateSecurityAttributesCall) Do(f func(*gitlab.BulkUpdateSecurityAttributesOptions, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockSecurityAttributesServiceInterfaceBulkUpdateSecurityAttributesCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockSecurityAttributesServiceInterfaceBulkUpdateSecurityAttributesCall) DoAndReturn(f func(*gitlab.BulkUpdateSecurityAttributesOptions, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockSecurityAttributesServiceInterfaceBulkUpdateSecurityAttributesCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// CreateSecurityAttributes mocks base method.
func (m *MockSecurityAttributesServiceInterface) CreateSecurityAttributes(namespaceID, categoryID int64, opt *gitlab.CreateSecurityAttributesOptions, options ...gitlab.RequestOptionFunc) ([]*gitlab.SecurityAttribute, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{namespaceID, categoryID, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "CreateSecurityAttributes", varargs...)
	ret0, _ := ret[0].([]*gitlab.SecurityAttribute)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// CreateSecurityAttributes indicates an expected call of CreateSecurityAttributes.
func (mr *MockSecurityAttributesServiceInterfaceMockRecorder) CreateSecurityAttributes(namespaceID, categoryID, opt any, options ...any) *MockSecurityAttributesServiceInterfaceCreateSecurityAttributesCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{namespaceID, categoryID, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "CreateSecurityAttributes", reflect.TypeOf((*MockSecurityAttributesServiceInterface)(nil).CreateSecurityAttributes), varargs...)
	return &MockSecurityAttributesServiceInterfaceCreateSecurityAttributesCall{Call: call}
}

// MockSecurityAttributesServiceInterfaceCreateSecurityAttributesCall wrap *gomock.Call
type MockSecurityAttributesServiceInterfaceCreateSecurityAttributesCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockSecurityAttributesServiceInterfaceCreateSecurityAttributesCall) Return(arg0 []*gitlab.SecurityAttribute, arg1 *gitlab.Response, arg2 error) *MockSecurityAttributesServiceInterfaceCreateSecurityAttributesCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockSecurityAttributesServiceInterfaceCreateSecurityAttributesCall) Do(f func(int64, int64, *gitlab.CreateSecurityAttributesOptions, ...gitlab.RequestOptionFunc) ([]*gitlab.SecurityAttribute, *gitlab.Response, error)) *MockSecurityAttributesServiceInterfaceCreateSecurityAttributesCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockSecurityAttributesServiceInterfaceCreateSecurityAttributesCall) DoAndReturn(f func(int64, int64, *gitlab.CreateSecurityAttributesOptions, ...gitlab.RequestOptionFunc) ([]*gitlab.SecurityAttribute, *gitlab.Response, error)) *MockSecurityAttributesServiceInterfaceCreateSecurityAttributesCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// DestroySecurityAttribute mocks base method.
func (m *MockSecurityAttributesServiceInterface) DestroySecurityAttribute(id int64, options ...gitlab.RequestOptionFunc) (*gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{id}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "DestroySecurityAttribute", varargs...)
	ret0, _ := ret[0].(*gitlab.Response)
	ret1, _ := ret[1].(error)
	return ret0, ret1
}

// DestroySecurityAttribute indicates an expected call of DestroySecurityAttribute.
func (mr *MockSecurityAttributesServiceInterfaceMockRecorder) DestroySecurityAttribute(id any, options ...any) *MockSecurityAttributesServiceInterfaceDestroySecurityAttributeCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{id}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "DestroySecurityAttribute", reflect.TypeOf((*MockSecurityAttributesServiceInterface)(nil).DestroySecurityAttribute), varargs...)
	return &MockSecurityAttributesServiceInterfaceDestroySecurityAttributeCall{Call: call}
}

// MockSecurityAttributesServiceInterfaceDestroySecurityAttributeCall wrap *gomock.Call
type MockSecurityAttributesServiceInterfaceDestroySecurityAttributeCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockSecurityAttributesServiceInterfaceDestroySecurityAttributeCall) Return(arg0 *gitlab.Response, arg1 error) *MockSecurityAttributesServiceInterfaceDestroySecurityAttributeCall {
	c.Call = c.Call.Return(arg0, arg1)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockSecurityAttributesServiceInterfaceDestroySecurityAttributeCall) Do(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockSecurityAttributesServiceInterfaceDestroySecurityAttributeCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockSecurityAttributesServiceInterfaceDestroySecurityAttributeCall) DoAndReturn(f func(int64, ...gitlab.RequestOptionFunc) (*gitlab.Response, error)) *MockSecurityAttributesServiceInterfaceDestroySecurityAttributeCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// ProjectUpdateSecurityAttribute mocks base method.
func (m *MockSecurityAttributesServiceInterface) ProjectUpdateSecurityAttribute(projectID int64, opt *gitlab.ProjectUpdateSecurityAttributeOptions, options ...gitlab.RequestOptionFunc) (*gitlab.SecurityAttributeProjectUpdateResult, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{projectID, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "ProjectUpdateSecurityAttribute", varargs...)
	ret0, _ := ret[0].(*gitlab.SecurityAttributeProjectUpdateResult)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// ProjectUpdateSecurityAttribute indicates an expected call of ProjectUpdateSecurityAttribute.
func (mr *MockSecurityAttributesServiceInterfaceMockRecorder) ProjectUpdateSecurityAttribute(projectID, opt any, options ...any) *MockSecurityAttributesServiceInterfaceProjectUpdateSecurityAttributeCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{projectID, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "ProjectUpdateSecurityAttribute", reflect.TypeOf((*MockSecurityAttributesServiceInterface)(nil).ProjectUpdateSecurityAttribute), varargs...)
	return &MockSecurityAttributesServiceInterfaceProjectUpdateSecurityAttributeCall{Call: call}
}

// MockSecurityAttributesServiceInterfaceProjectUpdateSecurityAttributeCall wrap *gomock.Call
type MockSecurityAttributesServiceInterfaceProjectUpdateSecurityAttributeCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockSecurityAttributesServiceInterfaceProjectUpdateSecurityAttributeCall) Return(arg0 *gitlab.SecurityAttributeProjectUpdateResult, arg1 *gitlab.Response, arg2 error) *MockSecurityAttributesServiceInterfaceProjectUpdateSecurityAttributeCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockSecurityAttributesServiceInterfaceProjectUpdateSecurityAttributeCall) Do(f func(int64, *gitlab.ProjectUpdateSecurityAttributeOptions, ...gitlab.RequestOptionFunc) (*gitlab.SecurityAttributeProjectUpdateResult, *gitlab.Response, error)) *MockSecurityAttributesServiceInterfaceProjectUpdateSecurityAttributeCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockSecurityAttributesServiceInterfaceProjectUpdateSecurityAttributeCall) DoAndReturn(f func(int64, *gitlab.ProjectUpdateSecurityAttributeOptions, ...gitlab.RequestOptionFunc) (*gitlab.SecurityAttributeProjectUpdateResult, *gitlab.Response, error)) *MockSecurityAttributesServiceInterfaceProjectUpdateSecurityAttributeCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}

// UpdateSecurityAttribute mocks base method.
func (m *MockSecurityAttributesServiceInterface) UpdateSecurityAttribute(id int64, opt *gitlab.UpdateSecurityAttributeOptions, options ...gitlab.RequestOptionFunc) (*gitlab.SecurityAttribute, *gitlab.Response, error) {
	m.ctrl.T.Helper()
	varargs := []any{id, opt}
	for _, a := range options {
		varargs = append(varargs, a)
	}
	ret := m.ctrl.Call(m, "UpdateSecurityAttribute", varargs...)
	ret0, _ := ret[0].(*gitlab.SecurityAttribute)
	ret1, _ := ret[1].(*gitlab.Response)
	ret2, _ := ret[2].(error)
	return ret0, ret1, ret2
}

// UpdateSecurityAttribute indicates an expected call of UpdateSecurityAttribute.
func (mr *MockSecurityAttributesServiceInterfaceMockRecorder) UpdateSecurityAttribute(id, opt any, options ...any) *MockSecurityAttributesServiceInterfaceUpdateSecurityAttributeCall {
	mr.mock.ctrl.T.Helper()
	varargs := append([]any{id, opt}, options...)
	call := mr.mock.ctrl.RecordCallWithMethodType(mr.mock, "UpdateSecurityAttribute", reflect.TypeOf((*MockSecurityAttributesServiceInterface)(nil).UpdateSecurityAttribute), varargs...)
	return &MockSecurityAttributesServiceInterfaceUpdateSecurityAttributeCall{Call: call}
}

// MockSecurityAttributesServiceInterfaceUpdateSecurityAttributeCall wrap *gomock.Call
type MockSecurityAttributesServiceInterfaceUpdateSecurityAttributeCall struct {
	*gomock.Call
}

// Return rewrite *gomock.Call.Return
func (c *MockSecurityAttributesServiceInterfaceUpdateSecurityAttributeCall) Return(arg0 *gitlab.SecurityAttribute, arg1 *gitlab.Response, arg2 error) *MockSecurityAttributesServiceInterfaceUpdateSecurityAttributeCall {
	c.Call = c.Call.Return(arg0, arg1, arg2)
	return c
}

// Do rewrite *gomock.Call.Do
func (c *MockSecurityAttributesServiceInterfaceUpdateSecurityAttributeCall) Do(f func(int64, *gitlab.UpdateSecurityAttributeOptions, ...gitlab.RequestOptionFunc) (*gitlab.SecurityAttribute, *gitlab.Response, error)) *MockSecurityAttributesServiceInterfaceUpdateSecurityAttributeCall {
	c.Call = c.Call.Do(f)
	return c
}

// DoAndReturn rewrite *gomock.Call.DoAndReturn
func (c *MockSecurityAttributesServiceInterfaceUpdateSecurityAttributeCall) DoAndReturn(f func(int64, *gitlab.UpdateSecurityAttributeOptions, ...gitlab.RequestOptionFunc) (*gitlab.SecurityAttribute, *gitlab.Response, error)) *MockSecurityAttributesServiceInterfaceUpdateSecurityAttributeCall {
	c.Call = c.Call.DoAndReturn(f)
	return c
}
